@@ -13,7 +13,19 @@
 
 import sys
 import uuid
-from typing import Any, Dict, List, Tuple
+from typing import Any, Callable, Dict, List, Tuple, Union
+
+from braket.device_schema.simulators import (
+    GateModelSimulatorDeviceCapabilities,
+    GateModelSimulatorDeviceParameters,
+)
+from braket.ir.jaqcd import Program
+from braket.task_result import (
+    AdditionalMetadata,
+    GateModelTaskResult,
+    ResultTypeValue,
+    TaskMetadata,
+)
 
 from braket.default_simulator.gate_operations import from_braket_instruction
 from braket.default_simulator.observables import Hermitian, TensorProduct
@@ -24,18 +36,7 @@ from braket.default_simulator.result_types import (
     from_braket_result_type,
 )
 from braket.default_simulator.simulation import StateVectorSimulation
-from braket.device_schema.simulators import (
-    GateModelSimulatorDeviceCapabilities,
-    GateModelSimulatorDeviceParameters,
-)
-from braket.ir.jaqcd import Program
 from braket.simulator import BraketSimulator
-from braket.task_result import (
-    AdditionalMetadata,
-    GateModelTaskResult,
-    ResultTypeValue,
-    TaskMetadata,
-)
 
 
 class DefaultSimulator(BraketSimulator):
@@ -43,9 +44,14 @@ class DefaultSimulator(BraketSimulator):
     DEVICE_ID = "default"
 
     def run(
-        self, circuit_ir: Program, qubit_count: int, shots: int = 0, *, batch_size: int = 1,
+        self,
+        circuit_ir: Program,
+        qubit_count: int,
+        shots: int = 0,
+        *,
+        batch_size: int = 1,
     ) -> GateModelTaskResult:
-        """ Executes the circuit specified by the supplied `circuit_ir` on the simulator.
+        """Executes the circuit specified by the supplied `circuit_ir` on the simulator.
 
         Args:
             circuit_ir (Program): ir representation of a braket circuit specifying the
@@ -181,9 +187,13 @@ class DefaultSimulator(BraketSimulator):
         not_none_observable_list = []
         qubit_observable_mapping = {}
         for result_type in observable_result_types:
-            obs_obj = result_type.observable
-            measured_qubits = obs_obj.measured_qubits
-            new_obs = DefaultSimulator._observable_hash(obs_obj)
+            new_obs = DefaultSimulator._observable_hash(result_type.observable)
+            obs_obj = (
+                DefaultSimulator._tensor_product_index_dict(result_type.observable, lambda x: x)
+                if isinstance(result_type.observable, TensorProduct)
+                else result_type.observable
+            )
+            measured_qubits = result_type.observable.measured_qubits
             if measured_qubits is None:
                 measured_qubits = list(range(qubit_count))
 
@@ -192,29 +202,55 @@ class DefaultSimulator(BraketSimulator):
                     f"Result type ({result_type.__class__.__name__}) Observable "
                     f"({obs_obj.__class__.__name__}) references invalid qubits {measured_qubits}"
                 )
-            duplicate = False
-            for qubit in measured_qubits:
+            for i in range(len(measured_qubits)):
+                qubit = measured_qubits[i]
+                new_qubit_obs = new_obs[i] if isinstance(new_obs, dict) else new_obs
                 # Validate that the same observable is requested for a qubit in the result types
                 existing_obs = qubit_observable_mapping.get(qubit)
                 if existing_obs:
-                    duplicate = True
-                    if existing_obs != new_obs:
+                    if existing_obs != new_qubit_obs:
                         raise ValueError(
                             f"Qubit {qubit} is already being measured in {existing_obs};"
                             f" cannot measure in {new_obs}."
                         )
                 else:
-                    qubit_observable_mapping[qubit] = new_obs
-            if not duplicate and not none_observable_mapping.get(new_obs):
-                not_none_observable_list.append(obs_obj)
+                    qubit_observable_mapping[qubit] = new_qubit_obs
+                    qubit_obs_obj = obs_obj[i] if isinstance(obs_obj, dict) else obs_obj
+                    if (
+                        not none_observable_mapping.get(new_qubit_obs)
+                        and qubit_obs_obj.measured_qubits.index(qubit) == 0
+                    ):
+                        qubit_obs_obj = obs_obj[i] if isinstance(obs_obj, dict) else obs_obj
+                        not_none_observable_list.append(qubit_obs_obj)
         return not_none_observable_list + unique_none_observables
 
     @staticmethod
-    def _observable_hash(observable: Observable) -> str:
+    def _tensor_product_index_dict(
+        observable: TensorProduct, callable: Callable[[Observable], Any]
+    ) -> Dict[int, Observable]:
+        obj_dict = {}
+        i = 0
+        factors = list(observable.factors)
+        total = len(factors[0].measured_qubits)
+        while factors:
+            if i >= total:
+                factors.pop(0)
+                if factors:
+                    total += len(factors[0].measured_qubits)
+            if factors:
+                obj_dict[i] = callable(factors[0])
+            i += 1
+        return obj_dict
+
+    @staticmethod
+    def _observable_hash(observable: Observable) -> Union[str, Dict[int, str]]:
         if isinstance(observable, Hermitian):
             return str(hash(str(observable.matrix.tostring())))
         elif isinstance(observable, TensorProduct):
-            return ",".join(DefaultSimulator._observable_hash(obs) for obs in observable.factors)
+            # Dict of target index to observable hash
+            return DefaultSimulator._tensor_product_index_dict(
+                observable, DefaultSimulator._observable_hash
+            )
         else:
             return str(observable.__class__.__name__)
 
@@ -246,7 +282,7 @@ class DefaultSimulator(BraketSimulator):
 
     @staticmethod
     def _formatted_measurements(simulation: StateVectorSimulation) -> List[List[str]]:
-        """ Retrieves formatted measurements obtained from the specified simulation.
+        """Retrieves formatted measurements obtained from the specified simulation.
 
         Args:
             simulation (StateVectorSimulation): Simulation to use for obtaining the measurements.
@@ -262,7 +298,9 @@ class DefaultSimulator(BraketSimulator):
 
     @staticmethod
     def _create_results_obj(
-        results: List[Dict[str, Any]], circuit_ir: Program, simulation: StateVectorSimulation,
+        results: List[Dict[str, Any]],
+        circuit_ir: Program,
+        simulation: StateVectorSimulation,
     ) -> GateModelTaskResult:
         result_dict = {
             "taskMetadata": TaskMetadata(
